[Pkg-mozext-commits] [compactheader] 257/441: Fix incompatibility with lightning/show-inout add-ons. Added mozmill test to confirm fix.

David Prévot taffit at moszumanska.debian.org
Wed Mar 18 12:29:07 UTC 2015


This is an automated email from the git hooks/post-receive script.

taffit pushed a commit to branch master
in repository compactheader.

commit 043c5d71852983ff6506fb562223fb05bb18bbd7
Author: Joachim.Herb at gmx.de <Joachim.Herb at gmx.de>
Date:   Mon Aug 8 23:52:08 2011 +0200

    Fix incompatibility with lightning/show-inout add-ons.
    Added mozmill test to confirm fix.
    
    --HG--
    branch : preferences
---
 build.xml                                          |  4 ++
 .../CompactHeader/content/compactHeaderOverlay.js  |  9 +++--
 install.rdf                                        |  4 +-
 .../test-compactheader-preferences.js              | 45 ++++++++++++++--------
 test/download.sh                                   |  2 +-
 test/executeTests.pl                               | 22 ++++++-----
 test/testapps.csv                                  | 24 ++++++------
 7 files changed, 66 insertions(+), 44 deletions(-)

diff --git a/build.xml b/build.xml
index 92d1115..ec65c5b 100644
--- a/build.xml
+++ b/build.xml
@@ -102,6 +102,10 @@
                    byline="true"
                    match="(export XPI=.*CompactHeader-).*(.xpi)"
                    replace="\1${app.version}\2"/>
+    <replaceregexp file="${test.dir}/executeTests.pl"
+                   byline="true"
+                   match="(xpi =.*CompactHeader-).*(.xpi)"
+                   replace="\1${app.version}\2"/>
   </target>
 
 </project>
diff --git a/chrome/CompactHeader/content/compactHeaderOverlay.js b/chrome/CompactHeader/content/compactHeaderOverlay.js
index 70de3f8..5fbe5a9 100644
--- a/chrome/CompactHeader/content/compactHeaderOverlay.js
+++ b/chrome/CompactHeader/content/compactHeaderOverlay.js
@@ -599,10 +599,11 @@ org.mozdev.compactHeader.pane = function() {
     org.mozdev.compactHeader.debug.log("preferencesUpdate 2");
     wasHere = true;
     ReloadMessage();
-    var event = document.createEvent('Events');
-    event.initEvent('messagepane-loaded', false, true);
-    var headerViewElement = document.getElementById("msgHeaderView");
-    headerViewElement.dispatchEvent(event);
+    pub.coheOnLoadMsgHeaderPane();
+//    var event = document.createEvent('Events');
+//    event.initEvent('messagepane-loaded', false, true);
+//    var headerViewElement = document.getElementById("msgHeaderView");
+//    headerViewElement.dispatchEvent(event);
     setTimeout(clearReloadTimeout, 250);
     org.mozdev.compactHeader.debug.log("preferencesUpdate stop");
   }
diff --git a/install.rdf b/install.rdf
index 05a6af8..8561e71 100644
--- a/install.rdf
+++ b/install.rdf
@@ -6,7 +6,7 @@
 
 	<RDF:Description about="urn:mozilla:install-manifest">
 		<em:name>CompactHeader</em:name>
-		<em:version>1.4.2beta3</em:version>
+		<em:version>1.4.2beta4</em:version>
 		<em:description>Add ability to reduce header size to one or two lines. Linkify subjects in RSS feeds.</em:description>
 		<em:creator>Joachim Herb</em:creator>
 		<em:contributor>Zamula</em:contributor>
@@ -24,7 +24,7 @@
 			<RDF:Description>
 				<em:id>{3550f703-e582-4d05-9a08-453d09bdfdc6}</em:id>
 				<em:minVersion>5.0</em:minVersion>
-				<em:maxVersion>8.*</em:maxVersion>
+				<em:maxVersion>8.0a1</em:maxVersion>
 			</RDF:Description>
 		</em:targetApplication>
 	</RDF:Description>
diff --git a/test/download.sh b/test/download.sh
index f53f928..b6269da 100644
--- a/test/download.sh
+++ b/test/download.sh
@@ -20,7 +20,7 @@ else
   return 1;
 fi
 export TESTS=thunderbird-5.0.tests.zip
-export XPI=../../../AMO/CompactHeader-1.4.2beta3.xpi
+export XPI=../../../AMO/CompactHeader-1.4.2beta4.xpi
 export TESTDIR=test-5.0
 
 wget -P ftp -N $FTP_DIR/$APP
diff --git a/test/executeTests.pl b/test/executeTests.pl
index adb8101..51dc987 100644
--- a/test/executeTests.pl
+++ b/test/executeTests.pl
@@ -7,10 +7,10 @@ use POSIX;
 use Cwd;
 
 my $file = 'testapps.csv';
-my $xpi = "../../../AMO/CompactHeader-1.4.2beta3.xpi";
+my $xpi = "../../../AMO/CompactHeader-1.4.2beta4.xpi";
 my $ftpdir = "ftp";
 
-my ($ostype,$hosttype,$version,$ftppath,$app,$tests);
+my ($ostype,$hosttype,$version,$ftppath,$app,$tests,$lightning);
 my ($unpack, $unpackargs, $unpacktargetargs, $appbin);
 my ($sysname, $nodename, $release, $osversion, $machine) = POSIX::uname();
 
@@ -34,7 +34,7 @@ elsif ($^O eq "linux") {
 
 while (my $line = <F>)
 {
-  ($ostype,$hosttype,$version,$ftppath,$app,$tests) =
+  ($ostype,$hosttype,$version,$ftppath,$app,$tests,$lightning) =
     parse_csv($line);
 
   next if (not defined($ostype));
@@ -48,11 +48,13 @@ while (my $line = <F>)
     my $testdir = "test-$version";
 
     mkdir "$testdir";
-    system "wget", "-P", "$ftpdir", "-N", "$ftppath/$app";
-    system "wget", "-P", "$ftpdir", "-N", "$ftppath/$tests";
+    system "wget", "-P", "$ftpdir/$ostype-$hosttype-$version", "-N", "$ftppath/$app";
+    system "wget", "-P", "$ftpdir/$ostype-$hosttype-$version", "-N", "$ftppath/$tests";
+    system "wget", "-P", "$ftpdir/$ostype-$hosttype-$version", "-N", "$lightning";
 
-    system $unpack, $unpackargs, "$ftpdir/$app", $unpacktargetargs, $testdir;
-    system "unzip", "-o", "$ftpdir/$tests", "-d", $testdir, "-x", "*mochitest*", "*xpcshell*";
+
+    system $unpack, $unpackargs, "$ftpdir//$ostype-$hosttype-$version/$app", $unpacktargetargs, $testdir;
+    system "unzip", "-o", "$ftpdir//$ostype-$hosttype-$version/$tests", "-d", $testdir, "-x", "*mochitest*", "*xpcshell*";
 
     my $currentdir = getcwd;
 
@@ -73,8 +75,10 @@ while (my $line = <F>)
     chdir "$testdir/mozmill";
     system "pwd";
 
-#    my $log = `python runtest.py --binary=../thunderbird/$appbin --showall --show-errors -a $xpi -t compactheader 2>&1`;
-    my $log = `python runtest.py --binary=../thunderbird/$appbin --showall --show-errors -a $xpi -t compactheader/test-compactheader-toolbar.js 2>&1`;
+    my $log;
+#   $log = `python runtest.py --binary=../thunderbird/$appbin --showall --show-errors -a $xpi -t compactheader 2>&1`;
+    $log = $log . `python runtest.py --binary=../thunderbird/$appbin --showall --show-errors -a $xpi -t compactheader/test-compactheader-toolbar.js 2>&1`;
+    $log = $log . `python runtest.py --binary=../thunderbird/$appbin --showall --show-errors -a $xpi,../../ftp//$ostype-$hosttype-$version/lightning.xpi -t compactheader/test-compactheader-preferences.js 2>&1`;
 
     chdir "$currentdir";
     my @timeData = localtime(time);
diff --git a/test/testapps.csv b/test/testapps.csv
index 92329dc..b1470ab 100644
--- a/test/testapps.csv
+++ b/test/testapps.csv
@@ -1,12 +1,12 @@
-msys,i686,5.0,https://ftp.mozilla.org/pub/mozilla.org/thunderbird/nightly/5.0-candidates/build1/unsigned/win32/en-US/,thunderbird-5.0.zip,thunderbird-5.0.tests.zip,
-linux,i686,5.0,https://ftp.mozilla.org/pub/mozilla.org/thunderbird/nightly/5.0-candidates/build1/linux-i686/en-US/,thunderbird-5.0.tar.bz2,thunderbird-5.0.tests.zip,
-linux,x86_64,5.0,https://ftp.mozilla.org/pub/mozilla.org/thunderbird/nightly/5.0-candidates/build1/linux-x86_64/en-US/,thunderbird-5.0.tar.bz2,thunderbird-5.0.tests.zip,
-msys,i686,6.0b2,https://ftp.mozilla.org/pub/thunderbird/nightly/6.0b2-candidates/build1/unsigned/win32/en-US/,thunderbird-6.0b2.zip,thunderbird-6.0b2.tests.zip,
-linux,i686,6.0b2,https://ftp.mozilla.org/pub/thunderbird/nightly/6.0b2-candidates/build1/linux-i686/en-US/,thunderbird-6.0b2.tar.bz2,thunderbird-6.0b2.tests.zip,
-linux,x86_64,6.0b2,https://ftp.mozilla.org/pub/thunderbird/nightly/6.0b2-candidates/build1/linux-x86_64/en-US/,thunderbird-6.0b2.tar.bz2,thunderbird-6.0b2.tests.zip,
-msys,i686,7.0a2,https://ftp.mozilla.org/pub/thunderbird/nightly/latest-comm-aurora/,thunderbird-7.0a2.en-US.win32.zip,thunderbird-7.0a2.en-US.win32.tests.zip,
-linux,i686,7.0a2,https://ftp.mozilla.org/pub/thunderbird/nightly/latest-comm-aurora/,thunderbird-7.0a2.en-US.linux-i686.tar.bz2,thunderbird-7.0a2.en-US.linux-i686.tests.zip,
-linux,x86_64,7.0a2,https://ftp.mozilla.org/pub/thunderbird/nightly/latest-comm-aurora/,thunderbird-7.0a2.en-US.linux-x86_64.tar.bz2,thunderbird-7.0a2.en-US.linux-x86_64.tests.zip,
-msys,i686,8.0a1,https://ftp.mozilla.org/pub/thunderbird/nightly/latest-comm-central/,thunderbird-8.0a1.en-US.win32.zip,thunderbird-8.0a1.en-US.win32.tests.zip,
-linux,i686,8.0a1,https://ftp.mozilla.org/pub/thunderbird/nightly/latest-comm-central/,thunderbird-8.0a1.en-US.linux-i686.tar.bz2,thunderbird-8.0a1.en-US.linux-i686.tests.zip,
-linux,x86_64,8.0a1,https://ftp.mozilla.org/pub/thunderbird/nightly/latest-comm-central/,thunderbird-8.0a1.en-US.linux-x86_64.tar.bz2,thunderbird-8.0a1.en-US.linux-x86_64.tests.zip,
+"msys","i686","5.0","https://ftp.mozilla.org/pub/mozilla.org/thunderbird/nightly/5.0-candidates/build1/unsigned/win32/en-US/","thunderbird-5.0.zip","thunderbird-5.0.tests.zip","https://ftp.mozilla.org/pub/mozilla.org/calendar/lightning/releases/1.0b5rc3/win32/lightning.xpi"
+"linux","i686","5.0","https://ftp.mozilla.org/pub/mozilla.org/thunderbird/nightly/5.0-candidates/build1/linux-i686/en-US/","thunderbird-5.0.tar.bz2","thunderbird-5.0.tests.zip","https://ftp.mozilla.org/pub/mozilla.org/calendar/lightning/releases/1.0b5rc3/linux/lightning.xpi"
+"linux","x86_64","5.0","https://ftp.mozilla.org/pub/mozilla.org/thunderbird/nightly/5.0-candidates/build1/linux-x86_64/en-US/","thunderbird-5.0.tar.bz2","thunderbird-5.0.tests.zip","https://ftp.mozilla.org/pub/mozilla.org/calendar/lightning/releases/1.0b5rc3/linux/lightning.xpi"
+"msys","i686","6.0b2","https://ftp.mozilla.org/pub/thunderbird/nightly/6.0b2-candidates/build1/unsigned/win32/en-US/","thunderbird-6.0b2.zip","thunderbird-6.0b2.tests.zip","https://ftp.mozilla.org/pub/mozilla.org/calendar/lightning/releases/1.0b5rc3/win32/lightning.xpi"
+"linux","i686","6.0b2","https://ftp.mozilla.org/pub/thunderbird/nightly/6.0b2-candidates/build1/linux-i686/en-US/","thunderbird-6.0b2.tar.bz2","thunderbird-6.0b2.tests.zip","https://ftp.mozilla.org/pub/mozilla.org/calendar/lightning/releases/1.0b5rc3/linux/lightning.xpi"
+"linux","x86_64","6.0b2","https://ftp.mozilla.org/pub/thunderbird/nightly/6.0b2-candidates/build1/linux-x86_64/en-US/","thunderbird-6.0b2.tar.bz2","thunderbird-6.0b2.tests.zip","https://ftp.mozilla.org/pub/mozilla.org/calendar/lightning/releases/1.0b5rc3/linux/lightning.xpi"
+"msys","i686","7.0a2","https://ftp.mozilla.org/pub/thunderbird/nightly/latest-comm-aurora/","thunderbird-7.0a2.en-US.win32.zip","thunderbird-7.0a2.en-US.win32.tests.zip","https://ftp.mozilla.org/pub/mozilla.org/calendar/lightning/nightly/latest-comm-miramar/win32-xpi/lightning.xpi"
+"linux","i686","7.0a2","https://ftp.mozilla.org/pub/thunderbird/nightly/latest-comm-aurora/","thunderbird-7.0a2.en-US.linux-i686.tar.bz2","thunderbird-7.0a2.en-US.linux-i686.tests.zip","https://ftp.mozilla.org/pub/mozilla.org/calendar/lightning/nightly/latest-comm-miramar/linux-xpi/lightning.xpi"
+"linux","x86_64","7.0a2","https://ftp.mozilla.org/pub/thunderbird/nightly/latest-comm-aurora/","thunderbird-7.0a2.en-US.linux-x86_64.tar.bz2","thunderbird-7.0a2.en-US.linux-x86_64.tests.zip","https://ftp.mozilla.org/pub/mozilla.org/calendar/lightning/nightly/latest-comm-miramar/linux64-xpi/lightning.xpi"
+"msys","i686","8.0a1","https://ftp.mozilla.org/pub/thunderbird/nightly/latest-comm-central/","thunderbird-8.0a1.en-US.win32.zip","thunderbird-8.0a1.en-US.win32.tests.zip","https://ftp.mozilla.org/pub/mozilla.org/calendar/lightning/nightly/latest-comm-central/win32-xpi/lightning.xpi"
+"linux","i686","8.0a1","https://ftp.mozilla.org/pub/thunderbird/nightly/latest-comm-central/","thunderbird-8.0a1.en-US.linux-i686.tar.bz2","thunderbird-8.0a1.en-US.linux-i686.tests.zip","https://ftp.mozilla.org/pub/mozilla.org/calendar/lightning/nightly/latest-comm-central/linux-xpi/lightning.xpi"
+"linux","x86_64","8.0a1","https://ftp.mozilla.org/pub/thunderbird/nightly/latest-comm-central/","thunderbird-8.0a1.en-US.linux-x86_64.tar.bz2","thunderbird-8.0a1.en-US.linux-x86_64.tests.zip","https://ftp.mozilla.org/pub/mozilla.org/calendar/lightning/nightly/latest-comm-central/linux64-xpi/lightning.xpi"

diff --git a/test/compactheader/test-compactheader-preferences.js b/test/compactheader/test-compactheader-preferences.js
index e8b4800..12c6f8b 100644
--- a/test/compactheader/test-compactheader-preferences.js
+++ b/test/compactheader/test-compactheader-preferences.js
@@ -51,7 +51,8 @@ Cu.import('resource://mozmill/modules/controller.js', controller);
 // The WindowHelper module
 var WindowHelper;
 
-var folder;
+var folder1;
+var folder2;
 
 const PREF = "browser.preferences.instantApply";
 var prefBranch = Cc["@mozilla.org/preferences-service;1"]
@@ -83,7 +84,8 @@ function setupModule(module) {
   let meh = collector.getModule('mouse-event-helpers');
   meh.installInto(module);
 
-  folder = create_folder("MessageWindowC");
+  folder1 = create_folder("MessageWindowC");
+  folder2 = create_folder("MessageWindowD");
 
   // create a message that has the interesting headers that commonly
   // show up in the message header pane for testing
@@ -96,16 +98,17 @@ function setupModule(module) {
                               "Bcc": "Richard Roe <richard.roe at momo.invalid>"
                             }});
 
-  add_message_to_folder(folder, msg);
+  add_message_to_folder(folder1, msg);
 
-  // create a message that has
-
-  addToFolder("test encoded ISO-8859-1", messageBodyISO8859_1, folder, "iso-8859-1");
-  addToFolder("test encoded UTF-8", messageBodyUTF8, folder, "utf-8");
+  // create a message that has umlauts
+  addToFolder("test encoded ISO-8859-1", messageBodyISO8859_1, folder1, "iso-8859-1");
+  addToFolder("test encoded UTF-8", messageBodyUTF8, folder1, "utf-8");
 
   let msg = create_message();
-  add_message_to_folder(folder, msg);
+  add_message_to_folder(folder1, msg);
 
+  let msg = create_message();
+  add_message_to_folder(folder2, msg);
 }
 
 
@@ -114,27 +117,37 @@ function setupModule(module) {
  *  does not break the get messages button in main toolbar
  */
 function test_double_preference_change_ISO(){
-  select_message_in_folder(2);
+  select_message_in_folder(folder1, 2);
   assert_browser_text_present(mc.e("messagepane"), messageBodyISO8859_1);
-  open_preferences_dialog(mc, subtest_p1);
+  open_preferences_dialog(mc, subtest_change_twoline_linkify);
   mc.sleep(10);
   assert_browser_text_present(mc.e("messagepane"), messageBodyISO8859_1);
 }
 
 function test_double_preference_change_UTF(){
-  select_message_in_folder(3);
+  select_message_in_folder(folder1, 3);
   assert_browser_text_present(mc.e("messagepane"), messageBodyISO8859_1);
-  open_preferences_dialog(mc, subtest_p1);
+  open_preferences_dialog(mc, subtest_change_twoline_linkify);
   mc.sleep(10);
   assert_browser_text_present(mc.e("messagepane"), messageBodyISO8859_1);
 }
 
-function subtest_p1(aController) {
+function subtest_change_twoline_linkify(aController) {
   aController.click(aController.eid("checkboxCompactTwolineView"));
   aController.click(aController.eid("checkboxLinkify"));
   close_preferences_dialog(aController);
 }
 
+function test_single_preference_change_folder(){
+  select_message_in_folder(folder1, 3);
+  open_preferences_dialog(mc, subtest_change_twoline);
+  select_message_in_folder(folder2, 0);
+}
+
+function subtest_change_twoline(aController) {
+  aController.click(aController.eid("checkboxCompactTwolineView"));
+  close_preferences_dialog(aController);
+}
 
 /**
  *  Helper function to open an extra window, so that the 3pane
@@ -193,11 +206,11 @@ function close_preferences_dialog(aController) {
 }
 
 /**
  * Select message in current (global) folder.
  */
-function select_message_in_folder(aMessageNum)
+function select_message_in_folder(aFolder, aMessageNum)
 {
-  be_in_folder(folder);
+  be_in_folder(aFolder);
 
   // select and open the first message
   let curMessage = select_click_row(aMessageNum);
@@ -193,11 +206,11 @@ function close_preferences_dialog(aController) {
 
 /**
- * Select message in current (global) folder.
+ * Select message in current (global) folder1.
  */
-- 
Alioth's /usr/local/bin/git-commit-notice on /srv/git.debian.org/git/pkg-mozext/compactheader.git



More information about the Pkg-mozext-commits mailing list